/*
 * dlgapenf.c --- append font dialog
 * 
 * Copyright (c) 2019 Mariano Alvarez Fernandez (malfer@telefonica.net)
 *
 * This file is part of FEdit, a visual font editor for the MGRX font format
 *
 * FEdit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FEdit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FEdit. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <grgui.h>
#include <mgrxcolr.h>
#include "fedit.h"

#define COMMAND_OK           1
#define COMMAND_CANCEL       2

GUIDialog *fapendlg = NULL;
GUIGroup *fapengo = NULL;

int process_fapendlg_event(void *udata, GrEvent *ev)
{
    GUIDialog *d = (GUIDialog *)udata;
    GUIGroup *go = (GUIGroup *)(d->exdata);

    if (ev->type == GREV_COMMAND) {
        switch (ev->p1) {
            case COMMAND_OK :
                d->result = 1;
               return -1;
            case COMMAND_CANCEL :
                d->result = -1;
                return -1;
        }
    }

    return GUIGroupProcessEvent(go, ev);
}

int FApenDlgCreate(void)
{
    if (fapendlg) return 1; // dialog already created

    fapengo = GUIGroupCreate(14, 0, 0);
    if (fapengo == NULL) return 0;
    GUIObjectSetLabel(&(fapengo->o[0]), 0,   0,   0, 160, 30, GrNOCOLOR, WEBC_WHITE, "Font to append");
    GUIObjectSetEntry(&(fapengo->o[1]), 1, 160,   0, 160, 30, WEBC_WHITE, WEBC_BLACK, MAXLEN_FNAME, "");
    GUIObjectSetLabel(&(fapengo->o[2]), 2,   0,  40, 160, 30, GrNOCOLOR, WEBC_WHITE, "First source glyph");
    GUIObjectSetEntry(&(fapengo->o[3]), 3, 160,  40, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(fapengo->o[4]), 4,   0,  80, 160, 30, GrNOCOLOR, WEBC_WHITE, "Last source glyph");
    GUIObjectSetEntry(&(fapengo->o[5]), 5, 160,  80, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(fapengo->o[6]), 6,   0, 120, 160, 30, GrNOCOLOR, WEBC_WHITE, "First dest. glyph");
    GUIObjectSetEntry(&(fapengo->o[7]), 7, 160, 120, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(fapengo->o[8]), 8,   0, 160, 160, 30, GrNOCOLOR, WEBC_WHITE, "X origin");
    GUIObjectSetEntry(&(fapengo->o[9]), 9, 160, 160, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(fapengo->o[10]), 10,   0, 200, 160, 30, GrNOCOLOR, WEBC_WHITE, "Y origin");
    GUIObjectSetEntry(&(fapengo->o[11]), 11, 160, 200, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetButton(&(fapengo->o[12]), 12,  10, 250, 140, 40, WEBC_GREEN, WEBC_WHITE, "Ok", COMMAND_OK, 0, 0);
    GUIObjectSetButton(&(fapengo->o[13]), 13, 170, 250, 140, 40, WEBC_GREEN, WEBC_WHITE, "Cancel", COMMAND_CANCEL, 0, 0);
    GUIGroupSetSelected(fapengo, 1, 0);

    fapendlg = GUIGroupDialogCreate("Append glyphs from Font",
                                    fapengo, process_fapendlg_event);
    if (fapendlg == NULL) {
        GUIGroupDestroy(fapengo);
        return 0;
    }

    return 1;
}

void FApenDlgSetData(char *output, int fsglyph, int lsglyph,
                     int fdglyph, int xpivot, int ypivot)
{
    char s[121];
    
    if (!fapendlg) return;

    GUIGroupSetText(fapengo, 1, output);
    sprintf(s, "%d", fsglyph);
    GUIGroupSetText(fapengo, 3, s);
    sprintf(s, "%d", lsglyph);
    GUIGroupSetText(fapengo, 5, s);
    sprintf(s, "%d", fdglyph);
    GUIGroupSetText(fapengo, 7, s);
    sprintf(s, "%d", xpivot);
    GUIGroupSetText(fapengo, 9, s);
    sprintf(s, "%d", ypivot);
    GUIGroupSetText(fapengo, 11, s);
}

void FApenDlgGetData(char *output, int *fsglyph, int *lsglyph,
                     int *fdglyph, int *xpivot, int *ypivot)
{
    char *s;

    if (!fapendlg) return;

    s = GUIGroupGetText(fapengo, 1, GrGetChrtypeForUserEncoding());
    strcpy(output, s);
    free(s);
    s = GUIGroupGetText(fapengo, 3, GrGetChrtypeForUserEncoding());
    *fsglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(fapengo, 5, GrGetChrtypeForUserEncoding());
    *lsglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(fapengo, 7, GrGetChrtypeForUserEncoding());
    *fdglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(fapengo, 9, GrGetChrtypeForUserEncoding());
    *xpivot = atoi(s);
    free(s);
    s = GUIGroupGetText(fapengo, 11, GrGetChrtypeForUserEncoding());
    *ypivot = atoi(s);
    free(s);
}

int FApenDlgRun(void)
{
    if (!fapendlg) return -1; 

    fapendlg->result = -1;
    GUIDialogRun(fapendlg);
    return fapendlg->result;
}

