/*
 * dlgrsbox.c --- resize box dialog
 * 
 * Copyright (c) 2019 Mariano Alvarez Fernandez (malfer@telefonica.net)
 *
 * This file is part of FEdit, a visual font editor for the MGRX font format
 *
 * FEdit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FEdit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FEdit. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <grgui.h>
#include <mgrxcolr.h>
#include "fedit.h"

#define COMMAND_OK           1
#define COMMAND_CANCEL       2

GUIDialog *rsboxdlg = NULL;
GUIGroup *rsboxgo = NULL;

int process_rsboxdlg_event(void *udata, GrEvent *ev)
{
    GUIDialog *d = (GUIDialog *)udata;
    GUIGroup *go = (GUIGroup *)(d->exdata);

    if (ev->type == GREV_COMMAND) {
        switch (ev->p1) {
            case COMMAND_OK :
                d->result = 1;
               return -1;
            case COMMAND_CANCEL :
                d->result = -1;
                return -1;
        }
    }

    return GUIGroupProcessEvent(go, ev);
}

int RsBoxDlgCreate(void)
{
    if (rsboxdlg) return 1; // dialog already created

    rsboxgo = GUIGroupCreate(10, 0, 0);
    if (rsboxgo == NULL) return 0;
    GUIObjectSetLabel(&(rsboxgo->o[0]), 0, 120,  30, 120, 30, GrNOCOLOR, WEBC_WHITE, "     Top");
    GUIObjectSetEntry(&(rsboxgo->o[1]), 1, 120,   0, 120, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(rsboxgo->o[2]), 2,   0,  70, 120, 30, GrNOCOLOR, WEBC_WHITE, "     Left");
    GUIObjectSetEntry(&(rsboxgo->o[3]), 3,   0,  40, 120, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(rsboxgo->o[4]), 4, 240,  70, 120, 30, GrNOCOLOR, WEBC_WHITE, "    Right");
    GUIObjectSetEntry(&(rsboxgo->o[5]), 5, 240,  40, 120, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(rsboxgo->o[6]), 6, 120, 110, 120, 30, GrNOCOLOR, WEBC_WHITE, "    Bottom");
    GUIObjectSetEntry(&(rsboxgo->o[7]), 7, 120,  80, 120, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetButton(&(rsboxgo->o[8]), 8,  30, 160, 140, 40, WEBC_GREEN, WEBC_WHITE, "Ok", COMMAND_OK, 0, 0);
    GUIObjectSetButton(&(rsboxgo->o[9]), 9, 190, 160, 140, 40, WEBC_GREEN, WEBC_WHITE, "Cancel", COMMAND_CANCEL, 0, 0);
    GUIGroupSetSelected(rsboxgo, 1, 0);

    rsboxdlg = GUIGroupDialogCreate("Resize font box",
                                    rsboxgo, process_rsboxdlg_event);
    if (rsboxdlg == NULL) {
        GUIGroupDestroy(rsboxgo);
        return 0;
    }

    return 1;
}

void RsBoxDlgSetData(int top, int left, int right, int bottom)
{
    char s[121];
    
    if (!rsboxdlg) return;

    sprintf(s, "%d", top);
    GUIGroupSetText(rsboxgo, 1, s);
    sprintf(s, "%d", left);
    GUIGroupSetText(rsboxgo, 3, s);
    sprintf(s, "%d", right);
    GUIGroupSetText(rsboxgo, 5, s);
    sprintf(s, "%d", bottom);
    GUIGroupSetText(rsboxgo, 7, s);
}

void RsBoxDlgGetData(int *top, int *left, int *right, int *bottom)
{
    char *s;

    if (!rsboxdlg) return;

    s = GUIGroupGetText(rsboxgo, 1, GrGetChrtypeForUserEncoding());
    *top = atoi(s);
    free(s);
    s = GUIGroupGetText(rsboxgo, 3, GrGetChrtypeForUserEncoding());
    *left = atoi(s);
    free(s);
    s = GUIGroupGetText(rsboxgo, 5, GrGetChrtypeForUserEncoding());
    *right = atoi(s);
    free(s);
    s = GUIGroupGetText(rsboxgo, 7, GrGetChrtypeForUserEncoding());
    *bottom = atoi(s);
    free(s);
}

int RsBoxDlgRun(void)
{
    if (!rsboxdlg) return -1; 

    rsboxdlg->result = -1;
    GUIDialogRun(rsboxdlg);
    return rsboxdlg->result;
}

