/*
 * dlgurang.c --- uninit range dialog
 * 
 * Copyright (c) 2019 Mariano Alvarez Fernandez (malfer@telefonica.net)
 *
 * This file is part of FEdit, a visual font editor for the MGRX font format
 *
 * FEdit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FEdit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FEdit. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <grgui.h>
#include <mgrxcolr.h>
#include "fedit.h"

#define COMMAND_OK           1
#define COMMAND_CANCEL       2

GUIDialog *urangdlg = NULL;
GUIGroup *uranggo = NULL;

int process_urangdlg_event(void *udata, GrEvent *ev)
{
    GUIDialog *d = (GUIDialog *)udata;
    GUIGroup *go = (GUIGroup *)(d->exdata);

    if (ev->type == GREV_COMMAND) {
        switch (ev->p1) {
            case COMMAND_OK :
                d->result = 1;
               return -1;
            case COMMAND_CANCEL :
                d->result = -1;
                return -1;
        }
    }

    return GUIGroupProcessEvent(go, ev);
}

int URangDlgCreate(void)
{
    if (urangdlg) return 1; // dialog already created

    uranggo = GUIGroupCreate(6, 0, 0);
    if (uranggo == NULL) return 0;
    GUIObjectSetLabel(&(uranggo->o[0]), 0,   0,   0, 160, 30, GrNOCOLOR, WEBC_WHITE, "First glyph");
    GUIObjectSetEntry(&(uranggo->o[1]), 1, 160,   0, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(uranggo->o[2]), 2,   0,  40, 160, 30, GrNOCOLOR, WEBC_WHITE, "Last glyph");
    GUIObjectSetEntry(&(uranggo->o[3]), 3, 160,  40, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetButton(&(uranggo->o[4]), 4,  10, 90, 140, 40, WEBC_GREEN, WEBC_WHITE, "Ok", COMMAND_OK, 0, 0);
    GUIObjectSetButton(&(uranggo->o[5]), 5, 170, 90, 140, 40, WEBC_GREEN, WEBC_WHITE, "Cancel", COMMAND_CANCEL, 0, 0);
    GUIGroupSetSelected(uranggo, 1, 0);

    urangdlg = GUIGroupDialogCreate("Uninit glyph range",
                                    uranggo, process_urangdlg_event);
    if (urangdlg == NULL) {
        GUIGroupDestroy(uranggo);
        return 0;
    }

    return 1;
}

void URangDlgSetData(int fglyph, int lglyph)
{
    char s[121];
    
    if (!urangdlg) return;

    sprintf(s, "%d", fglyph);
    GUIGroupSetText(uranggo, 1, s);
    sprintf(s, "%d", lglyph);
    GUIGroupSetText(uranggo, 3, s);
}

void URangDlgGetData(int *fglyph, int *lglyph)
{
    char *s;

    if (!urangdlg) return;

    s = GUIGroupGetText(uranggo, 1, GrGetChrtypeForUserEncoding());
    *fglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(uranggo, 3, GrGetChrtypeForUserEncoding());
    *lglyph = atoi(s);
    free(s);
}

int URangDlgRun(void)
{
    if (!urangdlg) return -1; 

    urangdlg->result = -1;
    GUIDialogRun(urangdlg);
    return urangdlg->result;
}

